domino.graph


add-nodesclj/s

(add-nodes ctx inputs)
source

base-graph-ctxclj/s

(base-graph-ctx nodes)
source

conj-setclj/s

source

connected-nodes-mapclj/s

(connected-nodes-map graph edge-filter)
source

ctx-updaterclj/s

(ctx-updater
  edges
  {:domino.graph/keys [db executed-events] :domino.core/keys [model] :as ctx})

Reducer that updates context with new values updated in ctx from handler of each edge. New values are only stored when they are different from old values.

In changed cases, the following keys are updated: ::changed-paths => queue of affected paths ::db => temporary relevant db within context ::change-history => sequential history of changes. List of tuples of path-value pairs

Reducer that updates context with new values updated in ctx from
handler of each edge. New values are only stored when they are different
from old values.

In changed cases, the following keys are updated:
::changed-paths => queue of affected paths
::db => temporary relevant db within context
::change-history => sequential history of changes. List of tuples of path-value pairs
sourceraw docstring

empty-queueclj/s

source

eval-traversed-edgesclj/s

(eval-traversed-edges {:domino.graph/keys [changed-paths] :as ctx} graph)
(eval-traversed-edges {:domino.graph/keys [changes] :as ctx} graph origin)

Given an origin and graph, update context with edges.

When an node has been visited (as an input), it cannot be considered for an output

Given an origin and graph, update context with edges.

When an node has been visited (as an input), it cannot be considered for an output
sourceraw docstring

events-inputs-as-changesclj/s

(events-inputs-as-changes {:domino.core/keys [events-by-id db]} event-ids)
source

execute-eventsclj/s

(execute-events {:domino.core/keys [db graph] :as ctx} inputs)
source

(find-related input-node events)

finds other nodes related by eventset

finds other nodes related by eventset
sourceraw docstring

gen-ev-graphclj/s

(gen-ev-graph events)
source

gen-graphclj/s

(gen-graph events)
source

get-db-pathsclj/s

(get-db-paths model db paths)
source

input-nodesclj/s

(input-nodes events)
source

input?clj/s

(input? edge)
source

into-setclj/s

source

origin-pathclj/s

(origin-path graph origin)
source

reverse-edge-directionclj/s

(reverse-edge-direction graph)
source

subgraphsclj/s

(subgraphs graph)
source

traversed-edgesclj/s

(traversed-edges origin graph edge-filter)
source

try-eventclj/s

(try-event {:keys [handler inputs] :as event}
           {:domino.core/keys [model] :as ctx}
           db
           old-outputs)
source

validate-eventclj/s

(validate-event {:keys [outputs handler] :as ev} errors)
source

cljdoc builds & hosts documentation for Clojure/Script libraries